@@ -55,8 +55,8 @@ func Kernel(fileSystem vfs.FS) (map[string]interface{}, error) {
 // os-release specification.
 func OSRelease(system System) (map[string]interface{}, error) {
 	for _, filename := range []AbsPath{
-		"/usr/lib/os-release",
-		"/etc/os-release",
+		NewAbsPath("/usr/lib/os-release"),
+		NewAbsPath("/etc/os-release"),
 	} {
 		data, err := system.ReadFile(filename)
 		if errors.Is(err, fs.ErrNotExist) {
