@@ -1,24 +1,18 @@
 package cmd
 
 import (
-	"bytes"
-	"encoding/json"
 	"errors"
 	"fmt"
-	"os"
+	"io/fs"
 	"regexp"
 	"runtime"
 	"strconv"
-	"strings"
-	"text/template"
 
 	"github.com/go-git/go-git/v5"
 	"github.com/go-git/go-git/v5/plumbing"
 	"github.com/go-git/go-git/v5/plumbing/transport"
 	"github.com/go-git/go-git/v5/plumbing/transport/http"
 	"github.com/spf13/cobra"
-	"github.com/spf13/viper"
-	"golang.org/x/term"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
 )
@@ -104,6 +98,7 @@ func (c *Config) newInitCmd() *cobra.Command {
 			modifiesDestinationDirectory: "true",
 			persistentStateMode:          persistentStateModeReadWrite,
 			requiresSourceDirectory:      "true",
+			requiresWorkingTree:          "true",
 			runsCommands:                 "true",
 		},
 	}
@@ -132,25 +127,14 @@ func (c *Config) runInitCmd(cmd *cobra.Command, args []string) error {
 		c.init.purgeBinary = true
 	}
 
-	// Search upwards to find out if we're already in a git repository.
-	inWorkingCopy := false
-	workingCopyDirAbsPath := c.SourceDirAbsPath
-FOR:
-	for {
-		if info, err := c.baseSystem.Stat(workingCopyDirAbsPath.Join(".git")); err == nil && info.IsDir() {
-			inWorkingCopy = true
-			break FOR
-		}
-		prevWorkingCopyDirAbsPath := workingCopyDirAbsPath
-		workingCopyDirAbsPath = workingCopyDirAbsPath.Dir()
-		if len(workingCopyDirAbsPath) >= len(prevWorkingCopyDirAbsPath) {
-			break FOR
-		}
-	}
-
-	// If the working copy does not exist then init it or clone it.
-	if !inWorkingCopy {
-		rawSourceDir, err := c.baseSystem.RawPath(c.SourceDirAbsPath)
+	// If we're not in a working tree then init it or clone it.
+	gitDirAbsPath := c.WorkingTreeAbsPath.Join(".git")
+	switch info, err := c.baseSystem.Stat(gitDirAbsPath); {
+	case err == nil && info.IsDir():
+	case err == nil && !info.IsDir():
+		return fmt.Errorf("%s: not a directory", gitDirAbsPath)
+	case errors.Is(err, fs.ErrNotExist):
+		workingTreeRawPath, err := c.baseSystem.RawPath(c.WorkingTreeAbsPath)
 		if err != nil {
 			return err
 		}
@@ -160,10 +144,10 @@ FOR:
 		if len(args) == 0 {
 			if useBuiltinGit {
 				isBare := false
-				if _, err = git.PlainInit(string(rawSourceDir), isBare); err != nil {
+				if _, err = git.PlainInit(workingTreeRawPath.String(), isBare); err != nil {
 					return err
 				}
-			} else if err := c.run(c.SourceDirAbsPath, c.Git.Command, []string{"init", "--quiet"}); err != nil {
+			} else if err := c.run(c.WorkingTreeAbsPath, c.Git.Command, []string{"init", "--quiet"}); err != nil {
 				return err
 			}
 		} else {
@@ -180,7 +164,7 @@ FOR:
 					RecurseSubmodules: git.DefaultSubmoduleRecursionDepth,
 				}
 				isBare := false
-				_, err = git.PlainClone(string(rawSourceDir), isBare, &cloneOptions)
+				_, err = git.PlainClone(workingTreeRawPath.String(), isBare, &cloneOptions)
 				if errors.Is(err, transport.ErrAuthenticationRequired) {
 					var basicAuth http.BasicAuth
 					if basicAuth.Username, err = c.readLine(fmt.Sprintf("Username [default %q]? ", username)); err != nil {
@@ -193,7 +177,7 @@ FOR:
 						return err
 					}
 					cloneOptions.Auth = &basicAuth
-					_, err = git.PlainClone(string(rawSourceDir), isBare, &cloneOptions)
+					_, err = git.PlainClone(workingTreeRawPath.String(), isBare, &cloneOptions)
 				}
 				if err != nil {
 					return err
@@ -215,73 +199,19 @@ FOR:
 				}
 				args = append(args,
 					dotfilesRepoURL,
-					string(rawSourceDir),
+					workingTreeRawPath.String(),
 				)
-				if err := c.run("", c.Git.Command, args); err != nil {
+				if err := c.run(chezmoi.EmptyAbsPath, c.Git.Command, args); err != nil {
 					return err
 				}
 			}
 		}
-	}
-
-	// Find config template, execute it, and create config file.
-	configTemplateRelPath, ext, configTemplateContents, err := c.findConfigTemplate()
-	if err != nil {
+	case err != nil:
 		return err
 	}
-	var configFileContents []byte
-	if configTemplateRelPath == "" {
-		if err := c.persistentState.Delete(chezmoi.ConfigStateBucket, configStateKey); err != nil {
-			return err
-		}
-	} else {
-		configFileContents, err = c.createConfigFile(configTemplateRelPath, configTemplateContents)
-		if err != nil {
-			return err
-		}
 
-		// Validate the config.
-		v := viper.New()
-		v.SetConfigType(ext)
-		if err := v.ReadConfig(bytes.NewBuffer(configFileContents)); err != nil {
-			return err
-		}
-		if err := v.Unmarshal(&Config{}, viperDecodeConfigOptions...); err != nil {
-			return err
-		}
-
-		// Write the config.
-		configPath := c.init.configPath
-		if c.init.configPath == "" {
-			configPath = chezmoi.AbsPath(c.bds.ConfigHome).Join("chezmoi").Join(configTemplateRelPath)
-		}
-		if err := chezmoi.MkdirAll(c.baseSystem, configPath.Dir(), 0o777); err != nil {
-			return err
-		}
-		if err := c.baseSystem.WriteFile(configPath, configFileContents, 0o600); err != nil {
-			return err
-		}
-
-		configStateValue, err := json.Marshal(configState{
-			ConfigTemplateContentsSHA256: chezmoi.HexBytes(chezmoi.SHA256Sum(configTemplateContents)),
-		})
-		if err != nil {
-			return err
-		}
-		if err := c.persistentState.Set(chezmoi.ConfigStateBucket, configStateKey, configStateValue); err != nil {
-			return err
-		}
-	}
-
-	// Reload config if it was created.
-	if configTemplateRelPath != "" {
-		viper.SetConfigType(ext)
-		if err := viper.ReadConfig(bytes.NewBuffer(configFileContents)); err != nil {
-			return err
-		}
-		if err := viper.Unmarshal(c, viperDecodeConfigOptions...); err != nil {
-			return err
-		}
+	if err := c.createAndReloadConfigFile(); err != nil {
+		return err
 	}
 
 	// Apply.
@@ -308,79 +238,6 @@ FOR:
 	return nil
 }
 
-// createConfigFile creates a config file using a template and returns its
-// contents.
-func (c *Config) createConfigFile(filename chezmoi.RelPath, data []byte) ([]byte, error) {
-	funcMap := make(template.FuncMap)
-	chezmoi.RecursiveMerge(funcMap, c.templateFuncs)
-	chezmoi.RecursiveMerge(funcMap, map[string]interface{}{
-		"promptBool":    c.promptBool,
-		"promptInt":     c.promptInt,
-		"promptString":  c.promptString,
-		"stdinIsATTY":   c.stdinIsATTY,
-		"writeToStdout": c.writeToStdout,
-	})
-
-	t, err := template.New(string(filename)).Funcs(funcMap).Parse(string(data))
-	if err != nil {
-		return nil, err
-	}
-
-	sb := strings.Builder{}
-	templateData := c.defaultTemplateData()
-	if c.init.data {
-		chezmoi.RecursiveMerge(templateData, c.Data)
-	}
-	if err = t.Execute(&sb, templateData); err != nil {
-		return nil, err
-	}
-	return []byte(sb.String()), nil
-}
-
-func (c *Config) promptBool(field string) bool {
-	value, err := parseBool(c.promptString(field))
-	if err != nil {
-		returnTemplateError(err)
-		return false
-	}
-	return value
-}
-
-func (c *Config) promptInt(field string) int64 {
-	value, err := strconv.ParseInt(c.promptString(field), 10, 64)
-	if err != nil {
-		returnTemplateError(err)
-		return 0
-	}
-	return value
-}
-
-func (c *Config) promptString(field string) string {
-	value, err := c.readLine(fmt.Sprintf("%s? ", field))
-	if err != nil {
-		returnTemplateError(err)
-		return ""
-	}
-	return strings.TrimSpace(value)
-}
-
-func (c *Config) stdinIsATTY() bool {
-	file, ok := c.stdin.(*os.File)
-	if !ok {
-		return false
-	}
-	return term.IsTerminal(int(file.Fd()))
-}
-
-func (c *Config) writeToStdout(args ...string) string {
-	for _, arg := range args {
-		if _, err := c.stdout.Write([]byte(arg)); err != nil {
-			panic(err)
-		}
-	}
-	return ""
-}
-
 // guessDotfilesRepoURL guesses the user's username and dotfile repo from arg.
 func guessDotfilesRepoURL(arg string, ssh bool) (username, repo string) {
 	for _, dotfileRepoGuess := range dotfilesRepoGuesses {
